<?php
/**
 * Theme Metabox Options
 * @package laevento
 * @since 1.0.0
 */

if (!defined('ABSPATH')) {
    exit(); // exit if access directly
}

if (class_exists('CSF')) {

    $allowed_html = laevento()->kses_allowed_html(array('mark'));

    $prefix = 'laevento';

    /*-------------------------------------
      Post Format Options
  -------------------------------------*/
    CSF::createMetabox($prefix . '_post_video_options', array(
        'title' => esc_html__('Video Post Format Options', 'laevento'),
        'post_type' => 'post',
        'post_formats' => 'video'
    ));
    CSF::createSection($prefix . '_post_video_options', array(
        'fields' => array(
            array(
                'id' => 'video_url',
                'type' => 'text',
                'title' => esc_html__('Enter Video URL', 'laevento'),
                'desc' => wp_kses(__('enter <mark>video url</mark> to show in frontend', 'laevento'), $allowed_html)
            )
        )
    ));
    CSF::createMetabox($prefix . '_post_gallery_options', array(
        'title' => esc_html__('Gallery Post Format Options', 'laevento'),
        'post_type' => 'post',
        'post_formats' => 'gallery'
    ));
    CSF::createSection($prefix . '_post_gallery_options', array(
        'fields' => array(
            array(
                'id' => 'gallery_images',
                'type' => 'gallery',
                'title' => esc_html__('Select Gallery Photos', 'laevento'),
                'desc' => wp_kses(__('select <mark>gallery photos</mark> to show in frontend', 'laevento'), $allowed_html)
            )
        )
    ));
    /*-------------------------------------
      Page Container Options
    -------------------------------------*/
    CSF::createMetabox($prefix . '_page_container_options', array(
        'title' => esc_html__('Page Options', 'laevento'),
        'post_type' => array('page'),
    ));
    CSF::createSection($prefix . '_page_container_options', array(
        'title' => esc_html__('Layout & Colors', 'laevento'),
        'icon' => 'fa fa-columns',
        'fields' => Laevento_Group_Fields::page_layout()
    ));
    CSF::createSection($prefix . '_page_container_options', array(
        'title' => esc_html__('Header Footer & Breadcrumb', 'laevento'),
        'icon' => 'fa fa-header',
        'fields' => Laevento_Group_Fields::Page_Container_Options('header_options')
    ));
    CSF::createSection($prefix . '_page_container_options', array(
        'title' => esc_html__('Width & Padding', 'laevento'),
        'icon' => 'fa fa-file-o',
        'fields' => Laevento_Group_Fields::Page_Container_Options('container_options')
    ));
    //	Service Meta Box
    CSF::createMetabox($prefix . '_service_options', array(
        'title' => esc_html__('Service Options', 'laevento'),
        'post_type' => 'service',
    ));
    CSF::createSection($prefix . '_service_options', array(
        'fields' => array(
            array(
                'id' => 'service_icon',
                'type' => 'icon',
                'title' => esc_html__('Icon', 'laevento'),
                'desc' => wp_kses(__('Select Your Icon', 'laevento'), $allowed_html)
            )
        )
    ));

    /*-------------------------------------
     Team Options
    -------------------------------------*/
    CSF::createMetabox($prefix . '_team_options', array(
        'title' => esc_html__('Team Options', 'laevento'),
        'post_type' => array('team'),
        'priority' => 'high'
    ));
    CSF::createSection($prefix . '_team_options', array(
        'title' => esc_html__('Team Info', 'laevento'),
        'id' => 'laevento-info',
        'fields' => array(
            array(
                'id' => 'designation',
                'type' => 'text',
                'title' => esc_html__('Designation', 'laevento'),
            ),
            array(
                'id' => 'description',
                'type' => 'textarea',
                'title' => esc_html__('Description', 'laevento'),
            ),
            array(
                'id' => 'quote',
                'type' => 'textarea',
                'title' => esc_html__('Quote', 'laevento'),
                'default' => esc_html__('However, you will not be able to view combined metrics for all Videos separately from Downloads.', 'laevento'),
            ),
            array(
                'id' => 'email',
                'type' => 'text',
                'title' => esc_html__('Email', 'laevento'),
                'default' => esc_html__('jhon-harison@panthar.com', 'laevento'),
            ),
            array(
                'id' => 'phone',
                'type' => 'text',
                'title' => esc_html__('Phone', 'laevento'),
                'default' => esc_html__('+0 123 456 895', 'laevento'),
            ),
            array(
                'id' => 'address',
                'type' => 'text',
                'title' => esc_html__('Address', 'laevento'),
                'default' => esc_html__('Denpasar, Ealihot New York', 'laevento'),
            ),
        )
    ));
    CSF::createSection($prefix . '_team_options', array(
        'title' => esc_html__('Social Info', 'laevento'),
        'id' => 'social-info',
        'fields' => array(
            array(
                'id' => 'social-icons',
                'type' => 'repeater',
                'title' => esc_html__('Social Info', 'laevento'),
                'fields' => array(

                    array(
                        'id' => 'icon',
                        'type' => 'icon',
                        'title' => esc_html__('Title', 'laevento')
                    ),
                    array(
                        'id' => 'url',
                        'type' => 'text',
                        'title' => esc_html__('URL', 'laevento')
                    ),

                ),
            ),
        )
    ));

    //  Event Meta Box
    CSF::createMetabox($prefix.'_event_options',array(
        'title' => esc_html__('Event Options', 'laevento'),
        'post_type' => 'tribe_events',
    ));
    CSF::createSection($prefix . '_event_options', array(
        'title' => esc_html__('Event Speaker', 'laevento'),
        'id' => 'laevento-info',
        'fields' => array(
            array(
                'id' => 'event_hall_no',
                'type' => 'text',
                'title' => esc_html__('Event Hall No', 'laevento'),
            ),
            array(
                'id' => 'event_speaker',
                'type' => 'repeater',
                'title' => esc_html__('Event Speaker Info', 'laevento'),
                'fields' => array(
                    array(
                        'id' => 'image',
                        'type' => 'media',
                        'title' => esc_html__('Image', 'laevento'),
                    ),
                    array(
                        'id' => 'name',
                        'type' => 'text',
                        'title' => esc_html__('Name', 'laevento'),
                        'default' => esc_html__('Jhon Doe', 'laevento'),
                    ),
                    array(
                        'id' => 'designation',
                        'type' => 'text',
                        'title' => esc_html__('Designation', 'laevento'),
                        'default' => esc_html__('Founder Code Cani', 'laevento'),
                    ),
                ),
            ),
            array(
                'id' => 'event_btn_text',
                'type' => 'text',
                'title' => esc_html__('Event Btn Text', 'laevento'),
                'default' => esc_html__('Contact', 'laevento'),
            ),
            array(
                'id' => 'event_btn_url',
                'type' => 'text',
                'title' => esc_html__('Event Btn url', 'laevento'),
            ),
            array(
                'id' => 'event_days',
                'type' => 'text',
                'title' => esc_html__('Event Day', 'laevento'),
                'default' => esc_html__('<span>05</span> <span>06</span>', 'laevento'),
            ),
            array(
                'id' => 'event_dates',
                'type' => 'text',
                'title' => esc_html__('Event date', 'laevento'),
                'default' => esc_html__('OCT 2022', 'laevento'),
            ),
        )
    ));

    //  Post Category Meta Box
    CSF::createTaxonomyOptions($prefix.'_post_cat_options',array(
        'title' => esc_html__('Post Cat Options', 'laevento'),
        'taxonomy' => 'category',
    ));
    CSF::createSection($prefix . '_post_cat_options', array(
        'title' => esc_html__('Post Cat Options', 'laevento'),
        'id' => 'laevento-info',
        'fields' => array(
            array(
                'id' => 'post_cat_color',
                'type' => 'color',
                'title' => esc_html__('Post Cat Color', 'laevento'),
            ),
        )
    ));

}